Structs
- Line
Index - Index for fast byte offset to
LineColumnconversions. - Line
Number - Type-safe wrapper for a value whose logical range starts at
1, for instance the line or column numbers in a file - Source
Code - Source
Code Owned - Source
Location - A position into a source file represented by the line number and the offset to that character relative to the start of that line.
- Text
Size - A measure of text length. Also, equivalently, an index into text.