Crate rustpython_compiler_source

Crate rustpython_compiler_source 

Structs

LineIndex
Index for fast byte offset to LineColumn conversions.
LineNumber
Type-safe wrapper for a value whose logical range starts at 1, for instance the line or column numbers in a file
SourceCode
SourceCodeOwned
SourceLocation
A position into a source file represented by the line number and the offset to that character relative to the start of that line.
TextSize
A measure of text length. Also, equivalently, an index into text.

Enums

PositionEncoding